=======
LxStats
=======

|Latest Version| |Build Status| |Coverage Status|

LxStats is a library to access system and process statistics and metrics on
Linux systems.

It provides easy parsing of information from various files under the ``/proc``
and ``/sys`` filesystems.


.. |Latest Version| image:: https://img.shields.io/pypi/v/lxstats.svg
   :target: https://pypi.python.org/pypi/lxstats
.. |Build Status| image:: https://img.shields.io/travis/albertodonato/lxstats.svg
   :target: https://travis-ci.org/albertodonato/lxstats
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/albertodonato/lxstats/master.svg
   :target: https://codecov.io/gh/albertodonato/lxstats
